@@ -14,7 +14,7 @@
 #  limitations under the License.
 
 from elements import *
-import diagparser
+import parser
 from utils import XY
 
 
@@ -68,22 +68,22 @@ class DiagramTreeBuilder:
     def instantiate(self, group, tree):
         for stmt in tree.stmts:
             # Translate Node having group attribute to SubGraph
-            if isinstance(stmt, diagparser.Node):
+            if isinstance(stmt, parser.Node):
                 group_attr = [a for a in stmt.attrs if a.name == 'group']
                 if group_attr:
                     group_id = group_attr[-1]
                     stmt.attrs.remove(group_id)
 
                     if group_id.value != group.id:
-                        stmt = diagparser.SubGraph(group_id.value, [stmt])
+                        stmt = parser.SubGraph(group_id.value, [stmt])
 
             # Instantiate statements
-            if isinstance(stmt, diagparser.Node):
+            if isinstance(stmt, parser.Node):
                 node = DiagramNode.get(stmt.id)
                 node.set_attributes(stmt.attrs)
                 self.belong_to(node, group)
 
-            elif isinstance(stmt, diagparser.Edge):
+            elif isinstance(stmt, parser.Edge):
                 nodes = stmt.nodes.pop(0)
                 edge_from = [DiagramNode.get(n) for n in nodes]
                 for node in edge_from:
@@ -99,29 +99,29 @@ class DiagramTreeBuilder:
                         for node2 in edge_to:
                             edge = DiagramEdge.get(node1, node2)
                             if edge_type:
-                                attrs = [diagparser.Attr('dir', edge_type)]
+                                attrs = [parser.Attr('dir', edge_type)]
                                 edge.set_attributes(attrs)
                             edge.set_attributes(stmt.attrs)
 
                     edge_from = edge_to
 
-            elif isinstance(stmt, diagparser.SubGraph):
+            elif isinstance(stmt, parser.SubGraph):
                 subgroup = NodeGroup.get(stmt.id)
                 subgroup.level = group.level + 1
                 self.belong_to(subgroup, group)
                 self.instantiate(subgroup, stmt)
 
-            elif isinstance(stmt, diagparser.DefAttrs):
+            elif isinstance(stmt, parser.DefAttrs):
                 group.set_attributes(stmt.attrs)
 
-            elif isinstance(stmt, diagparser.AttrClass):
+            elif isinstance(stmt, parser.AttrClass):
                 name = unquote(stmt.name)
                 Diagram.classes[name] = stmt
 
-            elif isinstance(stmt, diagparser.AttrPlugin):
+            elif isinstance(stmt, parser.AttrPlugin):
                 self.diagram.set_plugin(stmt.name, stmt.attrs)
 
-            elif isinstance(stmt, diagparser.Statements):
+            elif isinstance(stmt, parser.Statements):
                 self.instantiate(group, stmt)
 
         group.update_order()
