@@ -15,7 +15,7 @@
 
 from blockdiag.noderenderer import NodeShape
 from blockdiag.noderenderer import install_renderer
-from blockdiag.utils import XY
+from blockdiag.utils import Box, XY
 
 
 class Input(NodeShape):
@@ -25,11 +25,10 @@ class Input(NodeShape):
         m = self.metrics.cell(self.node)
         r = self.metrics.cellsize * 3
 
-        textbox = (m.topleft.x + r, m.topleft.y,
-                   m.bottomright.x - r, m.bottomright.y)
+        self.textbox = Box(m.topleft.x + r, m.topleft.y,
+                           m.bottomright.x - r, m.bottomright.y)
 
     def render_shape(self, drawer, format, **kwargs):
-        outline = kwargs.get('outline')
         fill = kwargs.get('fill')
 
         m = self.metrics.cell(self.node)
@@ -50,11 +49,11 @@ class Input(NodeShape):
             drawer.polygon(shape, fill=self.node.color,
                              outline=self.node.color)
             drawer.loadImage(self.node.background, self.textbox)
-            drawer.polygon(shape, fill="none", outline=outline,
-                           style=self.node.style)
+            drawer.polygon(shape, fill="none",
+                           outline=self.node.linecolor, style=self.node.style)
         else:
-            drawer.polygon(shape, fill=self.node.color, outline=outline,
-                           style=self.node.style)
+            drawer.polygon(shape, fill=self.node.color,
+                           outline=self.node.linecolor, style=self.node.style)
 
 
 def setup(self):
