@@ -2,8 +2,9 @@
 
 import os
 import sys
+import tempfile
 import unittest2
-from utils import stderr_wrapper
+from utils import stderr_wrapper, assertRaises
 from cStringIO import StringIO
 from blockdiag.utils.collections import namedtuple
 from blockdiag.utils.fontmap import FontInfo, FontMap
@@ -31,33 +32,33 @@ class TestUtilsFontmap(unittest2.TestCase):
         FontInfo("my-cursive", None, 11)
         FontInfo("-fantasy", None, 11)
 
+    @assertRaises(AttributeError)
     def test_fontinfo_invalid_familyname1(self):
-        with self.assertRaises(AttributeError):
-            FontInfo("unknown", None, 11)
+        FontInfo("unknown", None, 11)
 
+    @assertRaises(AttributeError)
     def test_fontinfo_invalid_familyname2(self):
-        with self.assertRaises(AttributeError):
-            FontInfo("sansserif-", None, 11)
+        FontInfo("sansserif-", None, 11)
 
+    @assertRaises(AttributeError)
     def test_fontinfo_invalid_familyname3(self):
-        with self.assertRaises(AttributeError):
-            FontInfo("monospace-unkown", None, 11)
+        FontInfo("monospace-unkown", None, 11)
 
+    @assertRaises(AttributeError)
     def test_fontinfo_invalid_familyname4(self):
-        with self.assertRaises(AttributeError):
-            FontInfo("cursive-bold-bold", None, 11)
+        FontInfo("cursive-bold-bold", None, 11)
 
+    @assertRaises(AttributeError)
     def test_fontinfo_invalid_familyname4(self):
-        with self.assertRaises(AttributeError):
-            FontInfo("SERIF", None, 11)
+        FontInfo("SERIF", None, 11)
 
+    @assertRaises(TypeError)
     def test_fontinfo_invalid_fontsize1(self):
-        with self.assertRaises(TypeError):
-            FontInfo("serif", None, None)
+        FontInfo("serif", None, None)
 
+    @assertRaises(ValueError)
     def test_fontinfo_invalid_fontsize2(self):
-        with self.assertRaises(ValueError):
-            FontInfo("serif", None, '')
+        FontInfo("serif", None, '')
 
     def test_fontinfo_parse(self):
         font = FontInfo("serif", None, 11)
@@ -212,15 +213,17 @@ class TestUtilsFontmap(unittest2.TestCase):
         self.assertEqual(11, font1.size)
 
     def test_fontmap_duplicated_fontentry1(self):
-        _config = "[fontmap]\nsansserif: %s\nsansserif-normal: %s\n" % \
-                  (self.fontpath[0], self.fontpath[1])
-        config = StringIO(_config)
-        fmap = FontMap(config)
+        # this testcase is only for python2.6 or later
+        if sys.version_info > (2, 6):
+            _config = "[fontmap]\nsansserif: %s\nsansserif-normal: %s\n" % \
+                      (self.fontpath[0], self.fontpath[1])
+            config = StringIO(_config)
+            fmap = FontMap(config)
 
-        font1 = fmap.find()
-        self.assertEqual('sansserif', font1.generic_family)
-        self.assertEqual(self.fontpath[1], font1.path)
-        self.assertEqual(11, font1.size)
+            font1 = fmap.find()
+            self.assertEqual('sansserif', font1.generic_family)
+            self.assertEqual(self.fontpath[1], font1.path)
+            self.assertEqual(11, font1.size)
 
     @stderr_wrapper
     def test_fontmap_with_nodefault_fontentry(self):
@@ -284,7 +287,6 @@ class TestUtilsFontmap(unittest2.TestCase):
         self.assertEqual(None, font4.path)
         self.assertEqual(20, font4.size)
 
-    @stderr_wrapper
     def test_fontmap_using_fontalias(self):
         _config = ("[fontmap]\nserif-bold: %s\n" + \
                    "[fontalias]\ntest = serif-bold\n") % self.fontpath[0]
@@ -296,3 +298,43 @@ class TestUtilsFontmap(unittest2.TestCase):
         self.assertEqual('serif-bold', font1.familyname)
         self.assertEqual(self.fontpath[0], font1.path)
         self.assertEqual(20, font1.size)
+
+    def test_fontmap_by_file(self):
+        tmp = tempfile.mkstemp()
+
+        _config = "[fontmap]\nsansserif: %s\nsansserif-bold: %s\n" % \
+                  (self.fontpath[0], self.fontpath[1])
+
+        fp = os.fdopen(tmp[0], 'wt')
+        fp.write(_config)
+        fp.close()
+        fmap = FontMap(tmp[1])
+
+        font1 = fmap.find()
+        self.assertTrue(font1)
+        self.assertEqual('sansserif', font1.generic_family)
+        self.assertEqual(self.fontpath[0], font1.path)
+        self.assertEqual(11, font1.size)
+
+        os.unlink(tmp[1])
+
+    def test_fontmap_including_bom_by_file(self):
+        tmp = tempfile.mkstemp()
+
+        _config = ("\xEF\xBB\xBF[fontmap]\nsansserif: %s\n"
+                   "sansserif-bold: %s\n") % \
+                  (self.fontpath[0], self.fontpath[1])
+
+        try:
+            fp = os.fdopen(tmp[0], 'wt')
+            fp.write(_config)
+            fp.close()
+            fmap = FontMap(tmp[1])
+
+            font1 = fmap.find()
+            self.assertTrue(font1)
+            self.assertEqual('sansserif', font1.generic_family)
+            self.assertEqual(self.fontpath[0], font1.path)
+            self.assertEqual(11, font1.size)
+        finally:
+            os.unlink(tmp[1])
