@@ -18,11 +18,21 @@ import os
 import sys
 import copy
 import codecs
-from ordereddict import OrderedDict
-from ConfigParser import SafeConfigParser
+from config import ConfigParser
 from blockdiag.utils.collections import namedtuple
 
 
+def parse_fontpath(path):
+    if path is None:
+        return (None, None)
+
+    match = re.search('^(.*):(\d)$', path)
+    if match:
+        return (match.group(1), int(match.group(2)))
+    else:
+        return (path, None)
+
+
 class FontInfo(object):
     def __init__(self, family, path, size):
         self.path = path
@@ -93,16 +103,12 @@ class FontMap(object):
         self.set_default_font(None)
 
     def _parse_config(self, conffile):
-        if sys.version_info > (2, 6):
-            config = SafeConfigParser(dict_type=OrderedDict)
-        else:
-            config = SafeConfigParser()
+        config = ConfigParser()
 
         if hasattr(conffile, 'read'):
             config.readfp(conffile)
         elif os.path.isfile(conffile):
-            fd = codecs.open(conffile, 'r', 'utf-8')
-            config.readfp(fd)
+            config.read(conffile)
         else:
             msg = "fontmap file is not found: %s" % conffile
             raise RuntimeError(msg)
@@ -122,7 +128,8 @@ class FontMap(object):
         self.append_font(self.default_fontfamily, path)
 
     def append_font(self, fontfamily, path):
-        if path is None or os.path.isfile(path):
+        _path, index = parse_fontpath(path)
+        if path is None or os.path.isfile(_path):
             font = FontInfo(fontfamily, path, self.fontsize)
             self.fonts[font.familyname] = font
         else:
