@@ -17,10 +17,11 @@ import os
 import codecs
 from docutils import nodes
 from docutils.parsers import rst
-from blockdiag import diagparser
+from docutils.statemachine import ViewList
+from blockdiag import parser
 from blockdiag.command import detectfont
 from blockdiag.builder import ScreenNodeBuilder
-from blockdiag.DiagramDraw import DiagramDraw
+from blockdiag.drawer import DiagramDraw
 from blockdiag.utils.collections import namedtuple
 
 
@@ -138,7 +139,7 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
         return results
 
     def node2diagram(self, node):
-        tree = diagparser.parse_string(node['code'])
+        tree = parser.parse_string(node['code'])
         return ScreenNodeBuilder.build(tree)
 
     def node2image(self, node, diagram):
@@ -245,7 +246,8 @@ class BlockdiagDirective(BlockdiagDirectiveBase):
             row = nodes.row()
             for attr in desc:
                 entry = nodes.entry()
-                entry += nodes.paragraph(text=attr)
+                self.state.nested_parse(ViewList([attr], source=attr),
+                                        0, entry)
                 row += entry
             tbody += row
         tgroup += tbody
